@@ -18,9 +18,9 @@ async def main():
     block = get_logic_block_from_md_file(target_file)
     try:
         await block.evaluate()
-    except Exception:
+    except Exception as e:
         print("CHECK FAILED")
-        traceback.print_exc()
+        print(repr(e))
         exit(1)
     print("CHECK SUCCESS")
 
